<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Enter License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buy %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Breadcrumb</name>
    <message>
        <source>&amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go back</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Popular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Explore popular videos by category</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bye</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in &apos;2 of 3&apos;</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in &apos;Cool video - part 1&apos;</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in &apos;Cool series - episode 1&apos;</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Short</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HDR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>News</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubscriptionImportView</name>
    <message>
        <source>Open subscriptions.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>YouTube data (*.csv *.json)</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Subscribed to %n channel(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot open file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Didn&apos;t check for updates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version %1 download failed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Australia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canada</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>France</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Germany</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greece</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>India</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Israel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Japan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Peru</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Poland</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>United States</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomableUI</name>
    <message>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
